==> veracrypt_1.17.orig.tar.bz2: src/ExpandVolume/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ExpandVolume.rc
//
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORD_DLG                104
#define IDR_MENU                        106
#define IDD_EXPAND_PROGRESS_DLG         106
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDD_SIZE_DIALOG                 117
#define IDC_BOX_HELP                    1003
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_SPACE_LEFT                  1009
#define IDC_KB                          1011
#define IDC_MB                          1013
#define IDC_PROGRESS_BAR                1014
#define IDC_GB                          1015
#define IDC_TB                          1016
#define IDC_EXPAND_VOLUME_OLDSIZE       1017
#define IDC_EXPAND_VOLUME_NEWSIZE       1019
#define IDC_EXPAND_VOLUME_NAME          1020
#define IDC_EXPAND_VOLUME_INITSPACE     1021
#define IDC_EXPAND_FILE_SYSTEM          1022
#define IDC_RANDOM_BYTES                1023
#define IDC_BYTESWRITTEN                1024
#define IDC_WRITESPEED                  1025
#define IDC_MOUNT_OPTIONS               1026
#define IDC_TIMEREMAIN                  1027
#define IDC_KEY_FILES                   1030
#define IDC_VOLUME                      1033
#define IDC_PASSWORD                    1034
#define IDC_SELECT_DEVICE               1036
#define IDC_CREATE_VOLUME               1037
#define IDC_VOLUME_TOOLS                1038
#define IDC_SIZEBOX                     1038
#define IDC_WIPE_CACHE                  1039
#define IDC_MOUNTALL                    1040
#define IDC_SELECT_FILE                 1042
#define IDC_VOLUME_PROPERTIES           1044
#define IDT_RANDOM_POOL                 1047
#define IDT_VOL_NAME                    1047
#define IDT_HEADER_KEY                  1048
#define IDT_CURRENT_SIZE                1048
#define IDT_VOLUME                      1049
#define IDT_MASTER_KEY                  1049
#define IDT_NEW_SIZE                    1049
#define IDT_PASSWORD                    1050
#define IDT_DONE                        1050
#define IDT_SPEED                       1051
#define IDT_LEFT                        1052
#define IDT_INIT_SPACE                  1053
#define IDT_FILE_SYS                    1054
#define IDT_INIT_SPACE2                 1055
#define IDT_RANDOM_POOL2                1055
#define IDC_EXIT                        1060
#define IDC_UNMOUNTALL                  1063
#define IDC_SHOW_PASSWORD               1094
#define IDC_LOGO                        1095
#define IDC_SIZEDLG_TITLE               1111
#define IDC_INIT_NEWSPACE               1112
#define IDC_INFOEXPAND                  1113
#define IDC_BOX_STATUS                  1114
#define IDC_TRUECRYPT_MODE              1140
#define IDC_PREF_TEMP_CACHE_ON_MULTIPLE_MOUNT 1141
#define IDT_OLD_PIM                     1142
#define IDC_OLD_PIM                     1143
#define IDC_OLD_PIM_HELP                1144
#define ID_HOMEPAGE                     1145
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_FORUMS                      40005
#define IDM_BENCHMARK                   40006
#define IDM_TRAVELER                    40007
#define IDM_MOUNT_VOLUME_OPTIONS        40008
#define IDM_FAQ                         40009
#define IDM_REFRESH_DRIVE_LETTERS       40010
#define IDM_DEFAULT_KEYFILES            40011
#define IDM_WEBSITE                     40012
#define IDM_MOUNTALL                    40013
#define IDM_UNMOUNTALL                  40014
#define IDM_MOUNT_VOLUME                40015
#define IDM_CHANGE_PASSWORD             40016
#define IDM_VOLUME_WIZARD               40017
#define IDM_CREATE_VOLUME               40018
#define IDM_WIPE_CACHE                  40019
#define IDM_PREFERENCES                 40020
#define IDM_LICENSE                     40021
#define IDM_SELECT_FILE                 40022
#define IDM_SELECT_DEVICE               40023
#define IDM_VOLUME_PROPERTIES           40024
#define IDM_LANGUAGE                    40025
#define IDM_MOUNT_FAVORITE_VOLUMES      40026
#define IDM_SAVE_FAVORITE_VOLUMES       40027
#define IDM_BACKUP_VOL_HEADER           40028
#define IDM_RESTORE_VOL_HEADER          40029
#define IDM_HOTKEY_SETTINGS             40030
#define IDM_TC_DOWNLOADS                40031
#define IDM_NEWS                        40032
#define IDM_BUGREPORT                   40033
#define IDM_CONTACT                     40034
#define IDM_VERSION_HISTORY             40035
#define IDM_HOMEPAGE                    40036
#define IDM_TEST_VECTORS                40037
#define IDM_ADD_REMOVE_VOL_KEYFILES     40038
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40039
#define IDM_GENERATE_KEYFILE            40040
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40041
#define IDM_KEYFILE_GENERATOR           40042
#define IDM_SET_DEFAULT_KEYFILES        40043
#define IDM_ONLINE_TUTORIAL             40044
#define IDM_ONLINE_HELP                 40045
#define IDM_DONATIONS                   40046
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40047
#define IDM_CHANGE_SYS_PASSWORD         40048
#define IDM_CREATE_RESCUE_DISK          40049
#define IDM_PERMANENTLY_DECRYPT_SYS     40050
#define IDM_VERIFY_RESCUE_DISK          40051
#define IDM_SYSTEM_ENCRYPTION_STATUS    40052
#define IDM_ENCRYPT_SYSTEM_DEVICE       40053
#define IDM_SYSENC_RESUME               40054
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40055
#define IDM_CREATE_HIDDEN_OS            40056
#define IDM_TOKEN_PREFERENCES           40057
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40058
#define IDM_SYS_ENC_SETTINGS            40059
#define IDM_SYSENC_SETTINGS             40060
#define IDM_RESUME_INTERRUPTED_PROC     40061
#define IDM_MANAGE_TOKEN_KEYFILES       40062

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        120
#define _APS_NEXT_COMMAND_VALUE         40064
#define _APS_NEXT_CONTROL_VALUE         1146
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> veracrypt_1.26.7.orig.tar.bz2: src/ExpandVolume/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ExpandVolume.rc
//
#define IDD_MOUNT_DLG                   101
#define IDD_PASSWORD_DLG                104
#define IDR_MENU                        106
#define IDD_EXPAND_PROGRESS_DLG         106
#define IDR_MOUNT_RSRC_HEADER           109
#define IDS_UACSTRING                   110
#define IDB_LOGO_288DPI                 111
#define IDB_LOGO_96DPI                  112
#define IDD_SIZE_DIALOG                 117
#define IDC_BOX_HELP                    1003
#define IDC_CACHE                       1005
#define IDC_NO_HISTORY                  1006
#define IDC_DRIVELIST                   1007
#define IDC_SPACE_LEFT                  1009
#define IDC_KB                          1011
#define IDC_MB                          1013
#define IDC_PROGRESS_BAR                1014
#define IDC_GB                          1015
#define IDC_TB                          1016
#define IDC_EXPAND_VOLUME_OLDSIZE       1017
#define IDC_EXPAND_VOLUME_NEWSIZE       1019
#define IDC_EXPAND_VOLUME_NAME          1020
#define IDC_EXPAND_VOLUME_INITSPACE     1021
#define IDC_EXPAND_FILE_SYSTEM          1022
#define IDC_RANDOM_BYTES                1023
#define IDC_BYTESWRITTEN                1024
#define IDC_WRITESPEED                  1025
#define IDC_MOUNT_OPTIONS               1026
#define IDC_TIMEREMAIN                  1027
#define IDC_KEY_FILES                   1030
#define IDC_VOLUME                      1033
#define IDC_PASSWORD                    1034
#define IDC_SELECT_DEVICE               1036
#define IDC_CREATE_VOLUME               1037
#define IDC_VOLUME_TOOLS                1038
#define IDC_SIZEBOX                     1038
#define IDC_WIPE_CACHE                  1039
#define IDC_MOUNTALL                    1040
#define IDC_SELECT_FILE                 1042
#define IDC_VOLUME_PROPERTIES           1044
#define IDT_RANDOM_POOL                 1047
#define IDT_HEADER_KEY                  1048
#define IDT_MASTER_KEY                  1049
#define IDT_DONE                        1050
#define IDT_SPEED                       1051
#define IDT_LEFT                        1052
#define IDT_INIT_SPACE                  1053
#define IDT_FILE_SYS                    1054
#define IDC_EXIT                        1060
#define IDC_UNMOUNTALL                  1063
#define IDC_SHOW_PASSWORD               1094
#define IDC_LOGO                        1095
#define IDT_VOL_NAME                    1096
#define IDT_CURRENT_SIZE                1097
#define IDT_NEW_SIZE                    1098
#define IDT_VOLUME                      1099
#define IDT_PASSWORD                    1100
#define IDC_SIZEDLG_TITLE               1111
#define IDC_INIT_NEWSPACE               1112
#define IDC_INFOEXPAND                  1113
#define IDC_BOX_STATUS                  1114
#define IDC_TRUECRYPT_MODE              1140
#define IDC_PREF_TEMP_CACHE_ON_MULTIPLE_MOUNT 1141
#define IDT_OLD_PIM                     1142
#define IDC_OLD_PIM                     1143
#define IDC_OLD_PIM_HELP                1144
#define ID_HOMEPAGE                     1145
#define IDC_QUICKEXPAND                 1146
#define IDC_STEPSEXPAND                 1147
#define IDT_NEW_SIZE_BOX_TITLE          1148
#define IDM_HELP                        40001
#define IDM_ABOUT                       40002
#define IDM_UNMOUNT_VOLUME              40003
#define IDM_CLEAR_HISTORY               40004
#define IDM_FORUMS                      40005
#define IDM_BENCHMARK                   40006
#define IDM_TRAVELER                    40007
#define IDM_MOUNT_VOLUME_OPTIONS        40008
#define IDM_FAQ                         40009
#define IDM_REFRESH_DRIVE_LETTERS       40010
#define IDM_DEFAULT_KEYFILES            40011
#define IDM_WEBSITE                     40012
#define IDM_MOUNTALL                    40013
#define IDM_UNMOUNTALL                  40014
#define IDM_MOUNT_VOLUME                40015
#define IDM_CHANGE_PASSWORD             40016
#define IDM_VOLUME_WIZARD               40017
#define IDM_CREATE_VOLUME               40018
#define IDM_WIPE_CACHE                  40019
#define IDM_PREFERENCES                 40020
#define IDM_LICENSE                     40021
#define IDM_SELECT_FILE                 40022
#define IDM_SELECT_DEVICE               40023
#define IDM_VOLUME_PROPERTIES           40024
#define IDM_LANGUAGE                    40025
#define IDM_MOUNT_FAVORITE_VOLUMES      40026
#define IDM_SAVE_FAVORITE_VOLUMES       40027
#define IDM_BACKUP_VOL_HEADER           40028
#define IDM_RESTORE_VOL_HEADER          40029
#define IDM_HOTKEY_SETTINGS             40030
#define IDM_TC_DOWNLOADS                40031
#define IDM_NEWS                        40032
#define IDM_BUGREPORT                   40033
#define IDM_CONTACT                     40034
#define IDM_VERSION_HISTORY             40035
#define IDM_HOMEPAGE                    40036
#define IDM_TEST_VECTORS                40037
#define IDM_ADD_REMOVE_VOL_KEYFILES     40038
#define IDM_REMOVE_ALL_KEYFILES_FROM_VOL 40039
#define IDM_GENERATE_KEYFILE            40040
#define IDM_CHANGE_HEADER_KEY_DERIV_ALGO 40041
#define IDM_KEYFILE_GENERATOR           40042
#define IDM_SET_DEFAULT_KEYFILES        40043
#define IDM_ONLINE_TUTORIAL             40044
#define IDM_ONLINE_HELP                 40045
#define IDM_DONATIONS                   40046
#define IDM_CHANGE_SYS_HEADER_KEY_DERIV_ALGO 40047
#define IDM_CHANGE_SYS_PASSWORD         40048
#define IDM_CREATE_RESCUE_DISK          40049
#define IDM_PERMANENTLY_DECRYPT_SYS     40050
#define IDM_VERIFY_RESCUE_DISK          40051
#define IDM_SYSTEM_ENCRYPTION_STATUS    40052
#define IDM_ENCRYPT_SYSTEM_DEVICE       40053
#define IDM_SYSENC_RESUME               40054
#define IDM_MOUNT_SYSENC_PART_WITHOUT_PBA 40055
#define IDM_CREATE_HIDDEN_OS            40056
#define IDM_TOKEN_PREFERENCES           40057
#define IDM_CLOSE_ALL_TOKEN_SESSIONS    40058
#define IDM_SYS_ENC_SETTINGS            40059
#define IDM_SYSENC_SETTINGS             40060
#define IDM_RESUME_INTERRUPTED_PROC     40061
#define IDM_MANAGE_TOKEN_KEYFILES       40062

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        120
#define _APS_NEXT_COMMAND_VALUE         40064
#define _APS_NEXT_CONTROL_VALUE         1149
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
